/*
 * SnapShot.java
 * Created on 2011/08/25
 *
 * Copyright (C) 2011-2013 Nippon Telegraph and Telephone Corporation
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */

package jp.co.ntt.oss.heapstats.container;

import java.util.Map;

/**
 * Contains information about the snapshots taken by the agent.
 */
public class SnapShot {
    /** a Snapshot Header Information. */
    private SnapShotHeader header;

    /** ObjectData Map key is tag, data is ObjectData. */
    private Map<Long, ObjectData> elements;

    /** a Heap Usage. */
    private long heapUsage;

    /**
     * Create a snapshot.
     */
    public SnapShot() {
        header = null;
        elements = null;
        heapUsage = 0;
    }

    /**
     * Set the header information of the snapshot.
     *
     * @param value Header
     */
    public final void setHeader(final SnapShotHeader value) {
        header = value;
    }

    /**
     * Return the header information of the snapshot.
     *
     * @return Return the SnapShotHeader
     */
    public final SnapShotHeader getHeader() {
        return header;
    }

    /**
     * Sets the list of objects that are loaded into the Java virtual machine.
     *
     * @param value the list of objects
     */
    public final void setElements(final Map<Long, ObjectData> value) {
        elements = value;
    }

    /**
     * Return the list of objects.
     *
     * @return Return the list of objects
     */
    public final Map<Long, ObjectData> getElements() {
        return elements;
    }

    /**
     * Set the heap usage of the snapshot taken at the time.
     *
     * @param value the heap usage
     */
    public final void setHeapUsage(final long value) {
        heapUsage = value;
    }

    /**
     * Return the Heap Usage.
     *
     * @return Return the Heap Usage
     */
    public final long getHeapUsage() {
        return heapUsage;
    }

}
